==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/request/EnvironmentvariabledefinitionRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Environmentvariabledefinition;
import microsoft.dynamics.crm.entity.collection.request.AsyncoperationCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.BulkdeletefailureCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.DuplicaterecordCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.EnvironmentvariablevalueCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.MailboxtrackingfolderCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.PrincipalobjectattributeaccessCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.ProcesssessionCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SyncerrorCollectionRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

@JsonIgnoreType
public class EnvironmentvariabledefinitionRequest extends EntityRequest<Environmentvariabledefinition> {

    public EnvironmentvariabledefinitionRequest(ContextPath contextPath, Optional<Object> value) {
        super(Environmentvariabledefinition.class, contextPath, SchemaInfo.INSTANCE, value);
    }

    public SystemuserRequest createdby() {
        return new SystemuserRequest(contextPath.addSegment("createdby"), Optional.empty());
    }

    public SystemuserRequest createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("createdonbehalfby"), Optional.empty());
    }

    public SystemuserRequest modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedby"), Optional.empty());
    }

    public SystemuserRequest modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedonbehalfby"), Optional.empty());
    }

    public SystemuserRequest owninguser() {
        return new SystemuserRequest(contextPath.addSegment("owninguser"), Optional.empty());
    }

    public TeamRequest owningteam() {
        return new TeamRequest(contextPath.addSegment("owningteam"), Optional.empty());
    }

    public PrincipalRequest ownerid() {
        return new PrincipalRequest(contextPath.addSegment("ownerid"), Optional.empty());
    }

    public BusinessunitRequest owningbusinessunit() {
        return new BusinessunitRequest(contextPath.addSegment("owningbusinessunit"), Optional.empty());
    }

    public SyncerrorCollectionRequest environmentvariabledefinition_SyncErrors() {
        return new SyncerrorCollectionRequest(
                        contextPath.addSegment("environmentvariabledefinition_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest environmentvariabledefinition_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("environmentvariabledefinition_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest environmentvariabledefinition_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(
                        contextPath.addSegment("environmentvariabledefinition_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest environmentvariabledefinition_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("environmentvariabledefinition_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest environmentvariabledefinition_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(
                        contextPath.addSegment("environmentvariabledefinition_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest environmentvariabledefinition_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("environmentvariabledefinition_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest environmentvariabledefinition_AsyncOperations() {
        return new AsyncoperationCollectionRequest(
                        contextPath.addSegment("environmentvariabledefinition_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest environmentvariabledefinition_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("environmentvariabledefinition_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest environmentvariabledefinition_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(
                        contextPath.addSegment("environmentvariabledefinition_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest environmentvariabledefinition_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("environmentvariabledefinition_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest environmentvariabledefinition_ProcessSession() {
        return new ProcesssessionCollectionRequest(
                        contextPath.addSegment("environmentvariabledefinition_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest environmentvariabledefinition_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("environmentvariabledefinition_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest environmentvariabledefinition_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(
                        contextPath.addSegment("environmentvariabledefinition_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest environmentvariabledefinition_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("environmentvariabledefinition_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest environmentvariabledefinition_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(
                        contextPath.addSegment("environmentvariabledefinition_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest environmentvariabledefinition_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("environmentvariabledefinition_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public EnvironmentvariablevalueCollectionRequest environmentvariabledefinition_environmentvariablevalue() {
        return new EnvironmentvariablevalueCollectionRequest(
                        contextPath.addSegment("environmentvariabledefinition_environmentvariablevalue"), Optional.empty());
    }

    public EnvironmentvariablevalueRequest environmentvariabledefinition_environmentvariablevalue(String environmentvariablevalueid) {
        return new EnvironmentvariablevalueRequest(contextPath.addSegment("environmentvariabledefinition_environmentvariablevalue").addKeys(new NameValue(environmentvariablevalueid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.47-sources.jar: microsoft/dynamics/crm/entity/request/EnvironmentvariabledefinitionRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Environmentvariabledefinition;
import microsoft.dynamics.crm.entity.collection.request.AsyncoperationCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.BulkdeletefailureCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.DuplicaterecordCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.EnvironmentvariablevalueCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.MailboxtrackingfolderCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.PrincipalobjectattributeaccessCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.ProcesssessionCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SyncerrorCollectionRequest;

@JsonIgnoreType
public class EnvironmentvariabledefinitionRequest extends EntityRequest<Environmentvariabledefinition> {

    public EnvironmentvariabledefinitionRequest(ContextPath contextPath, Optional<Object> value) {
        super(Environmentvariabledefinition.class, contextPath, value);
    }

    public SystemuserRequest createdby() {
        return new SystemuserRequest(contextPath.addSegment("createdby"), Optional.empty());
    }

    public SystemuserRequest createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("createdonbehalfby"), Optional.empty());
    }

    public SystemuserRequest modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedby"), Optional.empty());
    }

    public SystemuserRequest modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedonbehalfby"), Optional.empty());
    }

    public SystemuserRequest owninguser() {
        return new SystemuserRequest(contextPath.addSegment("owninguser"), Optional.empty());
    }

    public TeamRequest owningteam() {
        return new TeamRequest(contextPath.addSegment("owningteam"), Optional.empty());
    }

    public PrincipalRequest ownerid() {
        return new PrincipalRequest(contextPath.addSegment("ownerid"), Optional.empty());
    }

    public BusinessunitRequest owningbusinessunit() {
        return new BusinessunitRequest(contextPath.addSegment("owningbusinessunit"), Optional.empty());
    }

    public SyncerrorCollectionRequest environmentvariabledefinition_SyncErrors() {
        return new SyncerrorCollectionRequest(
                        contextPath.addSegment("environmentvariabledefinition_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest environmentvariabledefinition_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("environmentvariabledefinition_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest environmentvariabledefinition_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(
                        contextPath.addSegment("environmentvariabledefinition_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest environmentvariabledefinition_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("environmentvariabledefinition_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest environmentvariabledefinition_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(
                        contextPath.addSegment("environmentvariabledefinition_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest environmentvariabledefinition_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("environmentvariabledefinition_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest environmentvariabledefinition_AsyncOperations() {
        return new AsyncoperationCollectionRequest(
                        contextPath.addSegment("environmentvariabledefinition_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest environmentvariabledefinition_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("environmentvariabledefinition_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest environmentvariabledefinition_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(
                        contextPath.addSegment("environmentvariabledefinition_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest environmentvariabledefinition_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("environmentvariabledefinition_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest environmentvariabledefinition_ProcessSession() {
        return new ProcesssessionCollectionRequest(
                        contextPath.addSegment("environmentvariabledefinition_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest environmentvariabledefinition_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("environmentvariabledefinition_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest environmentvariabledefinition_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(
                        contextPath.addSegment("environmentvariabledefinition_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest environmentvariabledefinition_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("environmentvariabledefinition_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest environmentvariabledefinition_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(
                        contextPath.addSegment("environmentvariabledefinition_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest environmentvariabledefinition_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("environmentvariabledefinition_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public EnvironmentvariablevalueCollectionRequest environmentvariabledefinition_environmentvariablevalue() {
        return new EnvironmentvariablevalueCollectionRequest(
                        contextPath.addSegment("environmentvariabledefinition_environmentvariablevalue"), Optional.empty());
    }

    public EnvironmentvariablevalueRequest environmentvariabledefinition_environmentvariablevalue(String environmentvariablevalueid) {
        return new EnvironmentvariablevalueRequest(contextPath.addSegment("environmentvariabledefinition_environmentvariablevalue").addKeys(new NameValue(environmentvariablevalueid.toString())), Optional.empty());
    }

}
